@@ -11,5 +11,6 @@ suanpanTypes = {
     # "csv": Csv,
     "int": Int,
     "float": Float,
-    "number": Float
+    "number": Float,
+    "csv": Csv
 }
\ No newline at end of file
