@@ -15,7 +15,8 @@ class GlobalVars(dict):
 
     def __init__(self):
         self.pkgPath = os.path.dirname(os.path.dirname(__file__))
-        defaultEnvYaml = os.path.join(self.pkgPath, "suanpan/configs/defaultEnvs.yaml")
+        defaultEnvYaml = os.path.join(self.pkgPath,
+                                      "suanpan/configs/defaultEnvs.yaml")
         defaults = config.loadConfig(defaultEnvYaml)
         for k, v in self.getEnv(defaults).items():
             setattr(self, k, v)
@@ -53,7 +54,8 @@ class GlobalVars(dict):
         return {}
 
     def get(self, key, default=None):
-        return getattr(self, key, default)
+        return getattr(self, key, default) if getattr(self, key,
+                                                      default) else default
 
 
 g = GlobalVars()
