@@ -16,10 +16,7 @@ def run(component, *args, **kwargs):
             ".py") else component
         component = imports(component)
         if not isinstance(component, APP):
-            try:
-                return component(*args, **kwargs)
-            except:
-                return component()
+            return component(*args, **kwargs)
     return component.start(*args, **kwargs)
 
 
